require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module UDS
    module Bucket

      # DTO representing blob attributes.
      class BlobAttributes < UU::OS::REST::DTO

        # URI of the blob.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :uri

        # Binary data logical name or file name.
        # @param [String]
        # @return [String]
        attr_accessor :name

        # Binary data content-type.
        # @param [String]
        # @return [String]
        attr_accessor :content_type

        # Binary data encoding.
        # @param [String]
        # @return [String]
        attr_accessor :encoding

        # Binary data size (in bytes).
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :size

        # URI of person who created this blob.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :owner_uri

        # URI of application which created this blob.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :application_uri

        # Time when blob was created (in ISO format).
        # @param [String, Time]
        # @return [String]
        attr_accessor :timestamp

        # Time (in milliseconds) after which blob will be automatically deleted (depends on configuration of bucket where blob is placed).
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :timeout

        # Binary data MD5 checksum.
        # @param [String]
        # @return [String]
        attr_accessor :checksum

        def uri
          attributes[:uri]
        end

        def uri=(val)
          if val
            attributes[:uri] = UU::OS::UESURI.new(val)
          else
            attributes[:uri] = nil
          end
        end

        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def content_type
          attributes[:contentType]
        end

        def content_type=(val)
          attributes[:contentType] = val
        end

        def encoding
          attributes[:encoding]
        end

        def encoding=(val)
          attributes[:encoding] = val
        end

        def size
          attributes[:size]
        end

        def size=(val)
          attributes[:size] = val
        end

        def owner_uri
          attributes[:ownerUri]
        end

        def owner_uri=(val)
          if val
            attributes[:ownerUri] = UU::OS::UESURI.new(val)
          else
            attributes[:ownerUri] = nil
          end
        end

        def application_uri
          attributes[:applicationUri]
        end

        def application_uri=(val)
          if val
            attributes[:applicationUri] = UU::OS::UESURI.new(val)
          else
            attributes[:applicationUri] = nil
          end
        end

        def timestamp
          attributes[:timestamp]
        end

        def timestamp=(val)
          attributes[:timestamp] = val
        end

        def timeout
          attributes[:timeout]
        end

        def timeout=(val)
          attributes[:timeout] = val
        end

        def checksum
          attributes[:checksum]
        end

        def checksum=(val)
          attributes[:checksum] = val
        end

      end

    end
  end
end
